<?php

/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: logtail.php 1161 2009-09-11 17:08:39Z shaun $
 *
 * Complete HTML page include include CSS to output searched for logs.  This page requires $_REQUEST['from_addr'] and $_REQUEST['rcpt_addr'] 
 */

include_once('../includes/log_output.php');

/**
 * Flag to toggle error handling
 * @var bool $is_error default is false
 */
$is_error = false;

/**
 * Empty string container for error message
 * @var string $error_message 
 */
$error_message = "";

/**
 * Required REQUEST parameter
 * @var string $from_addr is set to $_REQUEST['from_addr']
 */
$from_addr = "";

/**
 * Required REQUEST parameter
 * @var string $rcpt_addr is set to $_REQUEST['rcpt_addr']
 */
$rcpt_addr = "";

$max_results = 0;

// Check to ensure required parameters are set and valid
if (!isset($_REQUEST) || (!isset($_REQUEST['from_addr']) || !isset($_REQUEST['rcpt_addr']))) {
    $is_error = true;
    $error_message = "Not enough search parameters";
} else {
    isset($_REQUEST['from_addr']) && $from_addr = strtolower($_REQUEST['from_addr']);
    isset($_REQUEST['rcpt_addr']) && $rcpt_addr = strtolower($_REQUEST['rcpt_addr']);
}
if (is_string($_REQUEST['result_limit']) && strlen($_REQUEST['result_limit']) > 0) {
    $max_results = (int)$_REQUEST['result_limit'];
}

if (!strlen($from_addr) && !strlen($rcpt_addr)) {
    $is_error = true;
    $error_message = "Not enough search parameters";
}

// Enable all error reporting
error_reporting(E_ALL);

?>

<html>
<head>
<style>
<?php

/**
 * dump inline css file css/magicspam-log.css
 */
echo file_get_contents("css/magicspam-log.css");

?>

</style>
</head>
<body class="log">
<div class="wrapper">
<?php
/**
 * include ../includes/config file
 */
include_once("../includes/config.php");
ini_set("include_path",INCLUDES);

/**
 * include class MagicSpamLog
 */
include("class.MagicSpamLog.php");

/**
 * include class MagicSpamControl
 */
include("class.MagicSpamControl.php");

// show error if set and exit
if ($is_error) {
    echo $error_message;
    exit(0);
}

/**
 * Create a MagicSpamLog object passing the LOG_DIR
 * @var MagicSpamLog $msLog
 */
$msLog = new MagicSpamLog(LOG_DIR);

/**
 * Base file set to LOG_DIR . mslog
 * @var string $baseFile
 */
$baseFile = LOG_DIR . "mslog";

/**
 * Max number of days pulling from MagicSpamControl
 * @var string $maxdays
 */
$maxdays = MagicSpamControl::get('logdays',7);
$i = (int)$maxdays;
$found = 0;

echo '<table class="logTable">';

// TODO: internationalize.
echo <<<END
<tr>
    <td class="logHeader">Date/Time</td>
    <td class="logHeader">Type</td>
    <td class="logHeader">MUA</td>
    <td class="logHeader">IP Address</td>
    <td class="logHeader">Host Name</td>
    <td class="logHeader">HELO</td>
    <td class="logHeader">From</td>
    <td class="logHeader">Recipient</td>
</tr>
END;
// process, format, and output while there is information to show
$append = 'even';
while ($i >= 0) {
    $file = $baseFile;
    if ($i > 0) {
        $file .= "." . $i;
    }
    if (file_exists($file)) {
        if ($fp = fopen($file,"r")) {
            while ($line = fgets($fp)) {
                $fstring = ".*";
                $tstring = ".*";
                $line_arr = line_to_arr($line);
                if (valid_log_array($line_arr)) {
                    $mfrom = $line_arr['logFrom'];
                    $mrcpt = $line_arr['logRcpt'];
                    if (strlen($from_addr) == 0) {
                        $mfrom = "";
                    } else {
                        $fstring = preg_replace("/\*/",".*",$from_addr);
                    }
                    if (strlen($rcpt_addr) == 0) {
                        $mrcpt = "";
                    } else {
                        $tstring = preg_replace("/\*/",".*",$rcpt_addr);
                    }

                    if (preg_match("/^{$fstring}$/i",$mfrom) && preg_match("/^{$tstring}$/", $mrcpt)) {
                        render_log_line($line_arr,$append);
                        $found++;
                        if ($append == 'even') {
                            $append = 'odd';
                        } else {
                            $append = 'even';
                        }
                        if ($max_results > 0) {
                            if ($found >= $max_results) {
                                $i = 0;
                                break;
                            }
                        }
                    }
                }
            }
            fclose($fp);
        }
    }
    $i--;

}
echo "</table>";
if ($found === 0) {
    // TODO: internationalize
    echo "No entries found";
}
?>
</div>
</body>
</html>
