<?php

/**
 * vim:et:sw=4:ts=4
 * 
 * A simple notification class which extends LMNotifications and communicates with MagicSpamControl.
 * 
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 * 
 * $Id: class.MSNotifications.php 1479 2010-09-19 06:42:08Z shaun $
 * 
 */

require_once('../lm-notification-client/class.LMNotifications.php');
require_once('class.MagicSpamControl.php');
require_once('config.php');

/**
 * A notification manager to update the notification aspect of MagicSpamControl.
 *
 * @return array $entries a list of new notifications
 */
class MSNotifications extends LMNotifications {

    /**
     * Calls the constructor of the parent class.  Passes the arguements 1, https://notifications.linuxmagic.com
     * and the locations of the controls file to it's parents constructor.
     */
    public function __construct() {
        $uri = 'https://notifications.linuxmagic.com';
        parent::__construct(1, $uri, CONTROLS);
    }

    /**
     * Gets recent notifications and compares to last read timestamp to return unread notification list.
     *
     * @return array $entries a list of unread notifications
     */
    public function getUnread() {
        // update local cache with any new notifications
        $this->getRecent();

        // grab timestamp of last 'read' notification
        $timestamp = MagicSpamControl::get('1.read', 0);

        // only return those entries which are newer then the last 'read' notification
        $entries = array();
        foreach ($this->getLocal()->getEntries() as $entry) {
            if ($entry->timestamp > $timestamp) {
                $entries[] = $entry;
            }
        }

        return $entries;
    }

    /**
     * Gets recent notifications.
     * Checks the time of the last  
     *
     * @return array a list of recent notifications
     */
    public function getRecent() {
        $timestamp = MagicSpamControl::get('1.last', 0);
        if (time() - $timestamp > 3600) {
            MagicSpamControl::set('1.last', time());
            return parent::getRecent();
        }
        return array();
    }
    
    /**
     * Sets all notification to read using current time.
     */
    public function markAllRead() {
        MagicSpamControl::set('1.read', time());
        $this->getUnread();
    }
}

?>
