<?php

require_once("class.MagicSpamExemption.php");
require_once("class.MagicSpamSection.php");

/**
 * vim:et:sw=4:ts=4
 *
 * An extendable section which represents an exemption list.
 *
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: class.MagicSpamExemptionSection.php 604 2008-12-23 20:16:03Z sean $
 * 
 */

class MagicSpamExemptionSection extends MagicSpamSection {
    /**
     * This object will hold the information for an exemption list, and the 
     * MagicSpamExemption object.
     *
     * @param string $type Type of exemption list - used for the various form 
     * 					   field names.
     * @param string $template Template to use when rendering this section.
     */
    function __construct($type, $template) {
        parent::__construct($template);
        
        $this->mse = MagicSpamExemption::getInstance();

        $this->type = $type;
        $this->set("type", $type);
    }
    
    /**
     * Destructor.
     */
    function __destruct() {
        
    }
    
    /**
     * Subclasses must override this method. Should return an array of the
     * exempt items for this list.
     * 
     * @return Array of exempt items.
     */
    function getExemptionList() {
        
    }

    /**
     * Prepare the section for rendering. If exemption values need to be added,
     * add them. Same with removal.
     */
    function prepare() {
        if (array_key_exists("add_exempt_" . $this->type, $_POST)) {
            $value = $_POST["add_exempt_" . $this->type];
            if ($this->validate($value)) {
                if ($this->mse->add($value,$this->type)) {
                    $msg = "Successfully added entry. ";
                    $add = $this->mse->getLastMessage();
                    if (isset($add)) {
                        $msg .= "<br>" . $add;
                    }
                    $this->set("success", $msg);
                } else if ($error = $this->mse->getLastError()) {
                    $this->set("error", $error);
                } else {
                    $this->set("error", "Error adding entry.");
                }
            } else {
                $this->set("error", "Invalid entry.");
            }
        }
        
        if (array_key_exists("remove_exempt_" . $this->type, $_POST)) {
            $value = $_POST["remove_exempt_" . $this->type];
            
            if ($this->mse->remove($value,$this->type)) {
                $this->set("success", "Successfully removed entry.");
            } else {
                $error = $this->mse->getLastError();
                if (is_string($error) && strlen($error)) {
                    $this->set("error", $error);
                } else {
                    $this->set("error", "Error removing entry.");
                }
            }
        }
    }
    
    /**
     * The method must be overriden by subclass. Validates the value given for
     * the current exemption list.
     *
     * @param string $value Value to validate.
     * @return true if $value is valid, false if not.
     */
    function validate($value) {
        return false;
    }
}

?>
