<?php

/**
 * vim:et:sw=4:ts=4
 * 
 * This class provides an easy interface between the log files for MagicSpam
 * and any PHP interfaces.
 *
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: class.MagicSpamLog.php 1026 2009-07-16 17:28:19Z shaun $
 * 
 */

class MagicSpamLog {
    /**
     * Creates a new MagicSpamLog object using the location and prefix specified.
     *
     * @param $dir      Directory where the MagicSpam logs are held
     * @param $prefix   What each log file starts with
     * @param $numDays  Number of days the logs are archived for
     */
    function __construct($dir = "/var/log/magicspam/", $prefix = "mslog", $numDays = 7) {
        $this->base = $dir . $prefix;
        $this->numberOfDays = $numDays;
    }

    /**
     * Destroys the MagicSpamLog object
     */
    function __destruct() {

    }

    /**
     * Retrieve the last $num lines from the log.
     *
     * @param $num How many lines do you want?
     *
     * @return Array of the last $num lines.
     */
    function tail($num = 10) {
        $results = array();
        $file = $this->base;
        $ntogo = $num;
        $i = 1;
        
        do {
            if (file_exists($file)) {
                // log entries can be up to 4096 bytes long, so the most we have to scan
                // is the last (4096 * $num) of the file.  We add one so we can skip the
                // first line (as the 4096 aligned offset may be in the middle of a line)
                $bytes_remaining = 4096 * (($num + 1) - count($results));
                $new_rows = array();
                $size = filesize($file);
                if ($fp = fopen($file, "r")) {
                    if ($size > $bytes_remaining) {
                        fseek($fp, -1 * $bytes_remaining, SEEK_END);
                        fgets($fp); // throw away the first (possibly partial) line
                    }
                    while ( $line = fgets($fp) ) {
                        if ((count($results) + count($new_rows)) >= $num) {
                            array_pop($new_rows);
                        }
                        array_unshift($new_rows, "$line");
                    }
                    fclose($fp);
                    foreach ($new_rows as $row) {
                        array_unshift($results,$row);
                    }
                    $ntogo = $num - count($results);
                }
                $file = $this->base . "." . $i;
                $i++;
            } else {
                $file = $this->base . "." . $i;
                $i++;
            }
        } while ( ($i < $this->numberOfDays) && ($ntogo > 0));

        return $results;
    }
}

?>
