<?php

/**
 * vim:et:sw=4:ts=4
 * 
 * Provides an encapsulated way of rendering HTML to the screen.
 * 
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 * 
 * $Id: class.MagicSpamPage.php 603 2008-12-23 18:35:18Z sean $
 *
 */

class MagicSpamPage {
    /**
     * Constructs an object to display the page and various sections on the
     * screen with the templates specified.
     *
     * @param string $pageTemplate Template to use to generate the page. This
     * 	                           template must call the renderSections() 
     *                             method.
     */
    function __construct($pageTemplate = false) {
        $this->template = ( $pageTemplate ? TEMPLATES . "/" . $pageTemplate : TEMPLATES . "/page.php" );
        $this->sections = array();
        
        if (!file_exists($this->template)) {
            throw new Exception("Invalid page template specified. ({$this->template})");
        }
    }
    
    /**
     * Destructor.
     *
     */
    function __destruct() {
        
    }
    
    /**
     * Adds a section to the end of the page.
     *
     * @param MagicSpamSection $section Section to add to the end of the page.
     */
    function addSection($section) {
        $this->sections[] = $section;
    }
    
    /**
     * Prepare the sections for rendering. This should be called before calling
     * the render() method.
     */
    function prepare() {
        foreach ($this->sections as $section) {
            $section->prepare();
        }
    }
    
    /**
     * Renders the page using the template specified in the constructor.
     *
     */
    function render() {
        $page = $this;
        
        include($this->template);
    }
    
    /**
     * Renders each section. This should be called by the page template.
     *
     */
    function renderSections() {
        foreach ($this->sections as $section) {
            $section->render();
        }
    }
}

?>
