<?php

/**
 * vim:et:sw=4:ts=4
 *
 * The encapsulation of a section in a page.
 * 
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved. 
 *
 * $Id: class.MagicSpamSection.php 603 2008-12-23 18:35:18Z sean $
 *
 */

class MagicSpamSection {
    /**
     * Each MagicSpamSection will have a unique identifier. We use this static
     * variable to make sure each section is, indeed, unique.
     *
     * @var int
     */
    static $uniqueID = 0;
    
    /**
     * Construct a new section using the template provided.
     *
     * @param string $template Template to use to render this section.
     */
    function __construct($template) {
        $this->template = TEMPLATES . $template;
        $this->templateVars = array();
        $this->id = "section_" . ( MagicSpamSection::$uniqueID++ );

        $this->set("section", $this);
        $this->set("id", $this->id);
        $this->set("thisPage", $_SERVER["REQUEST_URI"]);
        
        if (!file_exists($this->template)) {
            throw new Exception("Invalid template specified. ({$this->template})");
        }
    }
    
    /**
     * Destructor.
     *
     */
    function __destruct() {
        
    }
    
    /**
     * Unique identifier for this section. Usually used for named anchors.
     *
     * @return Unique section identifier.
     */
    function getID() {
        return $this->id;
    }
    
    /**
     * Gets the template variables which are currently set.
     *
     * @return array Template variables.
     */
    function getTemplateVars() {
        return $this->templateVars;
    }
    
    /**
     * Sets a key/value pair which can be used in the template.
     *
     * @param string $key Key that can be used in the template.
     * @param mixed $value Value which the key refers to. 
     */
    function set($key, $value) {
        $this->templateVars[$key] = $value;
    }

    /**
     * Takes any key/value pairs from the set() method and makes them available
     * for the template, then includes the template.
     */
    function render() {
        foreach ($this->templateVars as $key=>$value) {
            $$key = $value;
        }
        
        include($this->template);
    }

    /**
     * Prepare the section for rendering.
     */
    function prepare() {
    }
}

?>
