<?php

/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: class.MagicSpamStatus.php 612 2008-12-23 22:15:30Z sean $
 *
 */


require_once("class.MagicSpamControl.php");
require_once("class.MagicSpamLicense.php");

/**
 * Toggles the state of MagicSpam between active and inactive.  
 * MagicSpamStatus writes to the control file using MagicSpamControl based on information 
 * received from MagicSpamLicense. Control is set to active if license is active or pending.
 */
class MagicSpamStatus {

    /**
     * singlton object
     * @var MagicSpamStatus
     */
    private static $object;
    
    /**
     * Location of the register bin
     * @var string
     */
    private static $register_bin = REGISTER;

    /**
     * Location of the updater bin
     * @var string
     */
    private static $updater_bin = UPDATER;

    /**
     * Control flag
     * @var string
     */
    private static $control = "enabled";

    /**
     * Create a new MagicSpamStatus object.  Object creation will fail if the register and
     * updater binaries are not found.
     */
    private function __construct() {
    }

    /**
     * Creates an new MagicSpamStatus object if one is not set
     *
     * @return object MagicSpamStatus
     */
    public static function getInstance() {
        if (self::$object === null) {
            self::$object = new MagicSpamStatus;
        }

        return self::$object;
    }

    /**
     * Run the wrapper utility passing the specified arguments. If the utility
     * does not exit with a zero (0), the first variable of the object will be set
     * to the error message. 
     * 
     * @param string $args Arguments to pass to the wrapper utility.
    */ 
     public static function exec($args) {
        $ar = array();

        $cmd = self::$register_bin . " " . escapeshellarg($args);
        exec($cmd, $ar, $exitCode);

        if ($exitCode != 0) {
            throw new Exception(implode("<br />",$ar));
        }
    }

    /**
     * Update the lists
     */
    public static function startUpdater() {
        exec(self::$updater_bin . " > /dev/null 2>&1 &");
    }

    /**
     * Checks the control to determine if state is enabled.
     *
     * @return bool based on control status
     */
    public function isEnabled() {
        return ( MagicSpamControl::get(self::$control, 0) == 1 );
    }

   /**
    * Toggles the state between active and inactive
    */ 
    public function toggle() {
        if ($this->isEnabled()) {
            $this->disable();
        } else {
            $this->enable();
        }
    }

    /**
     * Enables MagicSpam by checking the license, sets the control file, update the lists.
     */
    public function enable() {
        if (!is_executable(self::$register_bin)) {
            throw new Exception("Missing Registration binary [" . self::$register_bin . "]");
        }

        if (!is_executable(self::$updater_bin)) {
            throw new Exception("Missing Updater binary [" . self::$updater_bin . "]");
        }

        // activate MagicSpam - this sets the enabled control file
        // NOTE: all logic related to checking if the license is valid etc. is done in the register call
        $this->exec("-a");

        // update the lists
        self::startUpdater();
    }


    /** 
     * Deactivate MagicSpam.  This sets the enabled control file.
     */
    public function disable() {
        $this->exec("-d");
    }
}

?>
