<?php

/**
 * vim:et:sw=4:ts=4
 * 
 * Provides an encapsulated way of rendering HTML to the screen.
 * 
 * Copyright (c) 2010 LinuxMagic Inc., All Rights Reserved.
 * 
 * $Id$
 *
 */
require_once('class.MagicSpamPage.php');

class MagicSpamTabPage extends MagicSpamPage {
    protected $defaultPage = '';

    /**
     * Constructs an object to display the page and various sections on the
     * screen with the templates specified.
     *
     * @param string $pageTemplate Template to use to generate the page. This
     * 	                           template must call the renderSections() 
     *                             method.
     */
    function __construct($pageTemplate = false) {
        $this->template = ( $pageTemplate ? TEMPLATES . "/" . $pageTemplate : TEMPLATES . "/tabpage.php" );
        $this->sections = array();
        
        if (!file_exists($this->template)) {
            throw new Exception("Invalid page template specified. ({$this->template})");
        }
    }
    
    /**
     * Destructor.
     *
     */
    function __destruct() {
        
    }

    function setDefault($def) {
        $this->defaultPage = $def;
    }
    
    /**
     * Adds a section to the end of the page.
     *
     * @param MagicSpamSection $section Section to add to the end of the page.
     */
    function addSection($section, $label, $title) {
        $this->sections[$label]['section'] = $section;
        $this->sections[$label]['title'] = $title;
    }
    
    /**
     * Prepare the sections for rendering. This should be called before calling
     * the render() method.
     */
    function prepare() {
        foreach ($this->sections as $label => $section) {
            $section['section']->prepare();
        }
    }
    
    /**
     * Renders the page using the template specified in the constructor.
     *
     */
    function render() {
        $page = $this;
        
        include($this->template);
    }
    
    /**
     * Renders each section. This should be called by the page template.
     *
     */
    function renderSections() {
        // render the menu
        echo '<ul class="lmtabnav">';
        foreach ($this->sections as $label => $section) {
            echo <<<END
<li><a href="javascript:void(null);" 
       onclick="activateTab(this,document.getElementById('{$label}'));"
       id="lm{$label}">{$section['title']}</a></li>
END;
        }
        echo "</ul>";
        // render the sections
        foreach ($this->sections as $label => $section) {
            echo "<div class=\"lmtab\" id=\"{$label}\" ";
            if (isset($_REQUEST['active_form'])) {
                if ($_REQUEST['active_form'] == $label) {
                    echo "style=\"display: block;\"";
                }
            } else {
                if ($label == $this->defaultPage) {
                    echo "style=\"display: block;\"";
                }
            }
            echo ">\n";
            $section['section']->render();
            echo "</div>";
        }
    }
}

?>
