<?php

/* vim:et:sw=4:ts=4
 *
 * The purpose of this class is to allow for the accessing and updating of the admin
 * email.  This is accomplished through the admin email section.
 *
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: class.MagicSpamAdminEmailSection.php 1161 2009-09-11 17:08:39Z shaun $
 *
 */

require_once("class.MagicSpamSection.php");
require_once("class.MagicSpamControl.php");
require_once("class.MagicSpamFromWhitelistSection.php");

/**
 * 
 */
class MagicSpamAdminEmailSection extends MagicSpamSection {

    /**
     * The control variable set to admin_email to be used in the control file.
     * @var string $control
     */
    private static $control = "admin_email";

    /**
     * Class constructor that allows editing of email address if passed a true variable. 
     *
     * @param bool $edit
     */
    function __construct($edit=false) {
        parent::__construct("adminemail.php");
        $email_address = MagicSpamControl::get(self::$control,"");
        $this->set("email_address",$email_address);
        if ($edit) {
            $this->set("editing",true);
        }
    }

    /**
     * Prepares to accept an email address.  Starts by checking to see if key email_address was posted,and then
     * validates posted address against the whitelsit section.  If validated, saves to control file; otherwise if
     * no email adedress was posted and template email = '', warning is thrown that alerts default to root.
     */
    function prepare() {
        if (array_key_exists("email_address",$_POST)) {
            if (!MagicSpamFromWhitelistSection::validate($_POST['email_address'])) {
                $this->set("error","Invalid email address");
            } else {
                try {
                    MagicSpamControl::set(self::$control,strtolower($_POST['email_address']));
                    $this->set("success","Address Updated");
                    $this->set("email_address",MagicSpamControl::get(self::$control,""));
                } catch(Exception $e) {
                    $this->set("error","Error saving setting");
                    $this->set("exception", $e);
                }
            }
        } else {
            if (!isset($this->templateVars["email_address"]) || $this->templateVars["email_address"] == "") {
                $this->set("error","Warning! Admin Email not set! Alerts will go to 'root' by default");
            }
        }
    }
}
?>
