<?php

/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: class.MagicSpamBMSSection.php 1161 2009-09-11 17:08:39Z shaun $
 *
 */

require_once("class.MagicSpamSection.php");
require_once("class.MagicSpamControl.php");

/**
 * Controls the output and requests for the BMS Section
 */
class MagicSpamBMSSection extends MagicSpamSection {
   
   /**
    * Control variable set to 'bms.enabled'
    * @var string $control
    */
    private static $control = "bms.enabled";

    /**
     * List containing BMS details
     * @var array $bvs
     */
    private $bms;

    /**
     * Sets the template file bms to the section object
     */
    function __construct() {
        parent::__construct("bms.php");

        $defaultEnabled = array(13, 36, 37, 38);
        $enabled = MagicSpamControl::getMulti(self::$control, $defaultEnabled);

        $this->bms = array(
            "4" => array(
                "description" => "UCEPROTECT-1",
                "url" => "http://www.uceprotect.net/en/index.php",
            ), "5" => array(
                "description" => "UCEPROTECT-2",
                "url" => "http://www.uceprotect.net/en/index.php",
            ), "13" => array(
                "description" => "PSBL",
                "url" => "http://psbl.surriel.com/",
            ), "23" => array(
                "description" => "SORBS-DUL",
                "url" => "http://www.sorbs.net/",
            ), "35" => array(
                "description" => "MIPSPACE",
                "url" => "http://www.mipspace.com/",
            ), "36" => array(
                "description" => "RATS-DYNA",
                "url" => "http://www.spamrats.com/",
            ), "37" => array(
                "description" => "RATS-NOPTR",
                "url" => "http://www.spamrats.com/",
            ), "38" => array(
                "description" => "RATS-SPAM",
                "url" => "http://www.spamrats.com/",
            ),
        );

        // set the default value for each rule
        foreach ($this->bms as $rule=>&$data) {
            $data["default"] = in_array($rule, $defaultEnabled);
            $data["enabled"] = in_array($rule, $enabled);
        }
    }
    
    /**
     * Accepts post variables to toggle rules' status before setting to templateVars
     */
    function prepare() {
        // special handling if we have been asked to reset the form.
        if (array_key_exists("reset", $_REQUEST)) {
            if (file_exists(CONTROLS . self::$control)) {
                unlink(CONTROLS . self::$control);
            }
            $defaultEnabled = array(13, 36, 37, 38);
            foreach ($this->bms as $rule=>&$data) {
                $data["default"] = in_array($rule, $defaultEnabled);
                $data["enabled"] = in_array($rule, $defaultEnabled);
            }
            MagicSpamControl::setMulti(self::$control, $defaultEnabled);
            $_REQUEST["bms"] = null;
            $this->set("success",true);
        }

        if (array_key_exists("bms", $_REQUEST) && is_array($_REQUEST["bms"])) {
            $enabled = array();
            $disabled = array();
            foreach ($_REQUEST["bms"] as $rule=>$value) {
                if (array_key_exists($rule, $this->bms)) {
                    if ($value == "true") {
                        $enabled[] = $rule;
                    } else {
                        $disabled[] = $rule;
                    }
                } 
            }

            try {
                MagicSpamControl::setMulti(self::$control, $enabled);
                $this->set("success", true);

                // save changes to our local rules var
                foreach ($this->bms as $rule => &$data) {
                    $data["enabled"] = in_array($rule, $enabled);
                }
            } catch (Exception $e) {
                $this->set("error", true);
                $this->set("exception", $e);
            }
        }
    }

    /**
     * Sets bms list to templateVars before rendering BMS section output
     */
    function render() {
        $this->set("bms", $this->bms);

        parent::render();
    }
}

?>
