<?php

/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: class.MagicSpamBasicStatsSection.php 1026 2009-07-16 17:28:19Z shaun $
 *
 */

require_once("class.MagicSpamSection.php");
require_once("class.MagicSpamControl.php");
require_once("class.MagicSpamLog.php");
require_once("class.rcptcounter.php");

/**
 * Controls the output and requests of the Basic Stats Section. Counts the SPAM, HAM, and EXEMPT for a given month.
 */
class MagicSpamBasicStatsSection extends MagicSpamSection {

    /**
     * RCPTCounter object to hold stats
     * @var RCPTCounter $stats
     */
    private $stats;

    /**
     * A list to track counts of SPAM, HAM, EXEMPT
     * @var array $counts
     */
    private $counts;

    /**
     *  Sets the basic_stats.php template file to the section object while initializing counts to 0.
     */
    public function __construct() {
        parent::__construct("basic_stats.php");

        $this->counts = array(
             "SPAM" => 0
            ,"HAM" => 0
            ,"EXEMPT" => 0
        );

    }

    /**
     * Creates the RCPTCounter object using current month, loads the stats and sets to local stats variable.
     * @return TRUE 
     */
    public function prepare() {
        $month = date("n");
        $this->stats = new RCPTCounter($month);
        $this->stats->load();
        return true;
    }

    /**
     * Counts the occurences of SPAM, HAM, and EXCEPT for today, sets to templateVars, and renders set template file.
     */
    public function render() {
        $day = date("j");

        $daydat = $this->stats->get_value($day,RCPT_TYPE_ALL);
        if (is_array($daydat)) {
            $this->counts['SPAM'] = $daydat['spam'];
            $this->counts['HAM'] = $daydat['ham'];
            $this->counts['EXEMPT'] = $daydat['exempt'];
        }
        $this->set("counts", $this->counts);

        parent::render();
    }
}

?>
