<?php

/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: class.MagicSpamIPExemptionSection.php 595 2008-12-19 19:42:07Z josh $
 *
 */

require_once("class.MagicSpamExemptionSection.php");

/**
 * IP exemption list section for MagicSpam.
 *
 */
class MagicSpamFromBlackListSection extends MagicSpamExemptionSection {
    /**
     * Stores information about an IP exemption list.
     */
    function __construct() {
        parent::__construct("fromblacklist", "blacklist.from.php");
    }
    
    /**
     * Gets the current entries in the IP exemption list.
     *
     * @return Array of exempt IPs.
     */
    function getExemptionList() {
        return $this->mse->getBlackListEntries();
    }
    
    /**
     * Validates the value passed in to make sure it is an IP address. This
     * function passes the value by referece so it can make sure it is properly
     * formed.
     * 
     * @param string $value Value to validate.
     * 
     * @return true if value is valid, false if not.
     */
    function validate(&$value) {
        $qtext = '[^\\x0d\\x22\\x5c\\x80-\\xff]';
        $dtext = '[^\\x0d\\x5b-\\x5d\\x80-\\xff]';
        $atom = '[^\\x00-\\x20\\x22\\x28\\x29\\x2c\\x2e\\x3a-\\x3c'.
                '\\x3e\\x40\\x5b-\\x5d\\x7f-\\xff]+';
        $quoted_pair = '\\x5c[\\x00-\\x7f]';
        $domain_literal = "\\x5b($dtext|$quoted_pair)*\\x5d";
        $quoted_string = "\\x22($qtext|$quoted_pair)*\\x22";
        $domain_ref = $atom;
        $sub_domain = "($domain_ref|$domain_literal)";
        $word = "($atom|$quoted_string)";
        $domain = "$sub_domain(\\x2e$sub_domain)*";
        $local_part = "$word(\\x2e$word)*";
        $addr_spec = "$local_part\\x40$domain";
        return preg_match("!^$addr_spec$!", $value) ? true : false;
    }
}

?>
