<?php

/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: class.MagicSpamIPExemptionSection.php 595 2008-12-19 19:42:07Z josh $
 *
 */

require_once("class.MagicSpamExemptionSection.php");

/**
 * IP exemption list section for MagicSpam.
 *
 */
class MagicSpamIPExemptionSection extends MagicSpamExemptionSection {
    /**
     * Stores information about an IP exemption list.
     */
    function __construct() {
        parent::__construct("ip", "exemption.ip.php");
    }
    
    /**
     * Gets the current entries in the IP exemption list.
     *
     * @return Array of exempt IPs.
     */
    function getExemptionList() {
        return $this->mse->getIPs();
    }
    
    /**
     * Validates the value passed in to make sure it is an IP address. This
     * function passes the value by referece so it can make sure it is properly
     * formed.
     * 
     * @param string $value Value to validate.
     * 
     * @return true if value is valid, false if not.
     */
    function validate(&$value) {
        $octets = explode(".", $value);
        if (count($octets) != 4) {
            return false;
        }

        // we do this loop for two reasons:
        // it checks each octet to make sure its between 0 and 255 inclusive
        // it will remove any leading zeros
        $ip = array();
        foreach ($octets as $octet) {
            if (is_numeric($octet) && $octet >= 0 && $octet <= 255) {
                $ip[] = (int) $octet;
            } else {
                return false;
            }
        }

        $value = implode(".", $ip);

        return true;
    }
}

?>
