<?php

/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: class.MagicSpamLicenseKeySection.php 729 2009-03-05 18:24:30Z shaun $
 *
 * This file allows access / updating to the MagicSpam License code.
 *
 */

require_once("class.MagicSpamSection.php");
require_once("class.MagicSpamLicense.php");

/**
 * Handles interaction with license code information.
 */
class MagicSpamLicenseKeySection extends MagicSpamSection {
    /**
     * Sets template to licensekey.php for section object
     */
    function __construct() {
        parent::__construct("licensekey.php");
    }

    /**
     * Prepares the ineraction with the license code through the set instance and posted variable. 
     * Editing is set to true if edit_key is posted or code for msLicense is set false, else if code key
     * is set editing is false and code is checked, if failure error is thrown and code is displayed;
     * otherwise, if update_key key is posted validation of update_key occurs. License variables are updated.
     */
    function prepare() {
        $msLicense = MagicSpamLicense::getInstance();
        $this->set("code", $msLicense->getCode());
        $this->set("editing", false);
        $this->set("nextupdate", $msLicense->getNextUpdate());
        $this->set("requester", $msLicense->getRequester());

        // no license set means we must enter one!
        if ($msLicense->getCode() === false) {
            $this->set("editing", true);
        }
        // now.. are we editing?
        if (is_array($_REQUEST) && array_key_exists('post_action', $_REQUEST)) {
            if ($_REQUEST['post_action'] == 'edit') {
                $this->set('editing', true);
            }
            if ($_REQUEST['post_action'] == 'update') {
                try {
                    $msLicense->update();
                    $this->set("success", intl("save_success"));
                }catch (Exception $e) {
                    $this->set('error', intl('save_error'));
                    $this->set("exception", $e);
                }
            }
        }
        if (is_array($_REQUEST) && array_key_exists("code", $_REQUEST)) {
            try {
                $msLicense->update($_REQUEST["code"]);
                $this->set("editing", false);
                $this->set("success", intl('save_success'));
                $this->set("code", $msLicense->getCode());
            } catch (Exception $e) {
                $this->set("error", "Invalid license key specified.");
                $this->set("exception", $e);
                $this->set("editing", true);
                // we want to show the new code they entered
                $this->set("code", $_REQUEST["code"]);
            }
        }
        // get (possibly new) data
        $this->set("expiry", $msLicense->getExpiry());
        $this->set("expired", $msLicense->isExpired());
        $this->set("nextupdate", $msLicense->getNextUpdate());
        $this->set("valid", $msLicense->isValid());
        $this->set("pending", $msLicense->isPending());
    }
}

?>
