<?php

/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id$
 *
 *
 */

require_once('class.MagicSpamSection.php');
require_once('class.rcptcounter.php');

/**
 *
 */
class MagicSpamStatsSection extends MagicSpamSection {
   
   /**
    * a RCPTCounter object to contain counter information
    * @var RCPTCounter $m_rcCounter
    */
    private $m_rcCounter;

    /**
     * String to contain error message if returned
     * @var string $m_strError
     */
    private $m_strError;

    /**
     * Flag to indicate success retrieval of counter information
     * @var bool $m_boolSuccess
     */
    private $m_boolSuccess;

    /**
     * 1 - 2 diget representation of current month
     * @var string $m_ulMonth
     */
    private $m_ulMonth;

    /**
     * DS_ followed by 3 character lowercase representation of current month
     * @var string $m_ulMonthFriendly
     */
    private $m_strMonthFriendly;

    /**
     * The current Timestamp
     * @var string $m_ulNow
     */
    private $m_ulNow;

    /**
     * Sets the template file stats to the section object and initialize m_boolSuccess as false.
     */
    public function __construct() {
        parent::__construct("stats.php");
        $this->m_boolSuccess = false;
    }

    /**
     * Prepares the RCPTCounter object based on current date or posted data.  Checks posted key 
     * active_month and sets accordingly or sets information based on current time.  It proceeds 
     * to intitalize local variable and load RCPTCounter data.
     */
    public function prepare() {
        $now = date('U');
        if (is_array($_REQUEST) && array_key_exists('active_month',$_REQUEST)) {
            $this->m_ulMonth = $_REQUEST['active_month'];
            $now = mktime(0,0,0,$this->m_ulMonth,1,date('y'));
        } else {
            $this->m_ulMonth = date('n');
        }
        $this->m_ulNow = $now;
        $this->m_strMonthFriendly = intl('DS_' . strtolower(date('M',$now)));
        $this->m_rcCounter = new RCPTCounter($this->m_ulMonth);
        if (!$this->m_rcCounter->load()) {
            $this->m_strError = $this->m_rcCounter->error();
            $this->m_boolSuccess = false;
        } else {
            $this->m_boolSuccess = true;
        }
    }

    /**
     * Sets templateVars and renders template page to output.  Outputs error if no statistics 
     * were found.
     */
    public function render() {
        // create an array object to set for gui.
        $STATS = array();
        $this->set("month_name",$this->m_strMonthFriendly);
        $this->set("month",$this->m_ulMonth);
        $year = 0;
        if (!$this->m_boolSuccess) {
            $this->set("error","No statistics found");
        } else {
            $n_days_in_month = date('t',$this->m_ulNow);
            $n_calc_ave = 0;
            $ave = 0;
            $tmp_total = 0;
            for ($c = 1; $c <= $n_days_in_month; $c++) {
                $STATS[$c] = $this->m_rcCounter->get_value($c,RCPT_TYPE_ALL);
                if ($STATS[$c]['timestamp'] != 0) {
                    $cmpyear = date('Y',$STATS[$c]['timestamp']);
                    if ($cmpyear > $year) {
                        $year = $cmpyear;
                    }
                }
            }
            for ($c = 1; $c <= $n_days_in_month; $c++) {
                if ($STATS[$c]['timestamp'] != 0) {
                    $cmpyear = date('Y', $STATS[$c]['timestamp']);
                    if ($cmpyear != $year) {
                        $STATS[$c] = NULL;
                    } else {
                        $tmp_total = $STATS[$c]['ham'] + $STATS[$c]['spam'] + $STATS[$c]['exempt'];
                        if ($tmp_total != 0) {
                            $ave += $tmp_total;
                            $n_calc_ave++;
                        }
                    }
                }
            }
            if ($n_calc_ave) {
                $ave = $ave / $n_calc_ave;
            }
            $this->set("daily_average",intval($ave));
            $this->set("stats",$STATS);
            if (isset($year) && $year > 0) {
                $this->set("year",$year);
            } 
        }
        parent::render();
    }
}

?>
