<?php
/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2010 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: api.php 8877 2010-02-17 23:41:41Z sean $
 *
 */

require_once('class.LMNotificationsLocalRepository.php');
require_once('class.LMNotificationsRemoteRepository.php');

class LMNotifications {
    protected $product = null;
    protected $uri = null;
    protected $data_dir = null;
    protected $local_cache = null;
    protected $remote = null;

    public function __construct($product, $uri, $data_dir) {
        if (!$product) {
            throw new Exception('No product defined.');
        } else if (!$uri) {
            throw new Exception('No uri defined.');
        } else if (!$data_dir) {
            throw new Exception('No data directory defined.');
        } else if (!is_dir($data_dir) || !is_readable($data_dir)) {
            throw new Exception('Data directory is not accessible.');
        }

        $this->product = $product;
        $this->uri = $uri;
        $this->data_dir = $data_dir;
    }

    public function get($number, $offset = 0) {
        // download any new messages and save them to local cache
        $this->getRecent();

        // return the requested entries
        $localrepo = $this->getLocal();
        return $localrepo->get($number, $offset);
    }

    public function getRecent() {
        $timestamp = null;
        $localrepo = $this->getLocal();
        $remoterepo = $this->getRemote();

        $lastentry = $localrepo->getMostRecent();
        if ($lastentry) {
            $timestamp = $lastentry->timestamp;
        }

        $entries = $remoterepo->getEntries($timestamp);
        $localrepo->addEntries($entries);
        $localrepo->save();

        return $entries;
    }

    public function getLastLocalEntry() {
        $local = $this->getLocalCache();
        $lastentry = $local->getMostRecent();
        return $lastentry->timestamp;
    }

    public function getLocal() {
        if ($this->local_cache === null) {
            $this->local_cache = new LMNotificationsLocalRepository($this->data_dir, $this->product);
        }
        
        return $this->local_cache;
    }

    public function getRemote() {
        if ($this->remote === null) {
            $this->remote = new LMNotificationsRemoteRepository($this->uri, $this->product);
        }
        return $this->remote;
    }
}
