<?php
/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2010 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: api.php 8877 2010-02-17 23:41:41Z sean $
 *
 */

require_once('class.LMNotificationsRepository.php');
require_once('class.LMNotificationsEntry.php');

class LMNotificationsLocalRepository extends LMNotificationsRepository {
    static private $cache_file_ext = '.cache';
    private $data_dir = null;

    public function __construct($data_dir, $product) {
        parent::__construct($product);
        $this->data_dir = $data_dir;
    }

    public function get($number, $offset = 0) {
        $this->load(0);

        $entries = $this->getEntries();
        $entries = array_slice($entries, $offset, $number, true);
        krsort($entries);
        reset($entries);

        return $entries;
    }

    public function setEntries($entries) {
        $this->entries = $entries;
    }

    public function addEntries($entries) {
        foreach ($entries as $entry) {
            $this->entries[$entry->timestamp] = $entry;
        }
    }

    protected function load($timestamp) {
        $file = $this->data_dir . DIRECTORY_SEPARATOR . $this->product . self::$cache_file_ext;
        if (!file_exists($file)) {
            return array();
        }
        if (!is_readable($file)) {
            // TODO: we should probably log an error here
            return array();
        }
        $contents = file_get_contents($file);
        if ($contents === false) {
            // TODO: should probably log something here too
            return array();
        }
        $entries = unserialize($contents);
        if ($entries === false) {
            // TODO: here too.. corrupt entries?
            return array();
        }
        if (!is_array($entries)) {
            // TODO: ..
            return array();
        }
        // now that we have our entries, add them to the list
        foreach ($entries as $entry) {
            if ($entry->timestamp > $timestamp) {
                $this->addEntry($entry);
            }
        }
    }

    public function save() {
        $file = $this->data_dir . DIRECTORY_SEPARATOR . $this->product . self::$cache_file_ext;
        if (file_exists($file) && !is_writeable($file)) {
            throw new Exception('Failed to write entries to local cache - cache file not writeable.');
        } else if (!is_writable(dirname($file))) {
            throw new Exception('Failed to write entries to local cache - cache directory does not exist, or is not writeable.');
        }
        if (file_put_contents($file, serialize($this->entries)) === false) {
            throw new Exception('Failed to write entries to local cache.');
        }
    }
}
