<?php
/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2010 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: api.php 8877 2010-02-17 23:41:41Z sean $
 *
 */

require_once('class.LMNotificationsRepository.php');
require_once('class.LMNotificationsEntry.php');
require_once('class.WebRequest.php');
require_once('class.WebResponse.php');

class LMNotificationsRemoteRepository extends LMNotificationsRepository {

    /** version of the format we are expecting back */
    static $version = 1;

    private $uri = null;
    private $user = null;
    private $pass = null;

    public function __construct($uri, $product, $user = null, $pass = null) {
        parent::__construct($product);
        if (!$uri) {
            throw new Exception('Invalid URI defined.');
        }
        $this->uri = $uri;
        $this->user = $user;
        $this->pass = $pass;
    }

    protected function load($timestamp) {
        $version = self::$version;
        $req = new WebRequest("{$this->uri}?timestamp={$timestamp}&feed_id={$this->product}&feed_version={$version}", WEBREQUEST_GET);
        $req->set_auth($this->user, $this->pass);
        $resp = $req->send();
        if ($resp->get_code() != 200) {
            throw new Exception('Failed to retrieve notifications.');
        }
        $entries = $this->parse($resp->data);
        foreach ($entries as $entry) {
            if ($entry->timestamp > $timestamp) {
                $this->addEntry($entry);
            }
        }
    }

    protected function parse($data) {
        $xml = simplexml_load_string($data);
        if ($xml === false) {
            throw new Exception('Invalid notification format received.');
        }
        $entries = array();
        foreach ($xml->posts->entry as $node) {
            $entry = new LMNotificationsEntry;
            $entry->timestamp = (string)$node->timestamp;
            $entry->title = (string)$node->title;
            $entry->author = (string)$node->author;
            $entry->severity = (string)$node->severity;
            $entry->short_description = (string)$node->short_description;
            $entry->description = (string)$node->description;
            $entry->type = (string)$node->type;
    
            $entries[] = $entry;
        }
        return $entries;
    }
}
