<?php
/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2010 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: api.php 8877 2010-02-17 23:41:41Z sean $
 *
 */

abstract class LMNotificationsRepository {
    protected $product = null;

    /** Array of entries where the key is the unix timestamp of the entry */
    protected $entries = null;

    public function __construct($product) {
        if (!$product) {
            throw new Exception('Invalid product defined.');
        }
        $this->product = $product;
    }

    public function getMostRecent($num = 1) {
        $entries = $this->getEntries();
        krsort($entries);
        reset($entries);
        return current($entries);
    }

    /**
     * Retrieve any entries which are newer than $timestamp.
     */
    public function getEntries($timestamp = null) {
        // TODO: could use some optimizations here. for now, we are just going to
        // regenerate the entries array with new data
        if (!is_numeric($timestamp)) {
            // if timestamp not specified, grab anything in the last month
            $timestamp = time() - ( 60 * 60 * 24 * 30 );
        }
        $this->entries = array();
        $this->load($timestamp);

        krsort($this->entries);
        reset($this->entries);

        return $this->entries;

    }

    protected function addEntry($entry) {
        if (!is_a($entry, 'LMNotificationsEntry')) {
            throw new Exception('Tried to add an invalid entry.');
        }
        $this->entries[$entry->timestamp] = $entry;
    }

    protected abstract function load($timestamp);
}
