<?php
/* vim:et:sw=4:ts=4
 * Copyright (c) 2009 LinuxMagic Inc., All Rights Reserved.
 * $Id: lib.webrequest.php 8739 2009-12-18 22:41:41Z sean $
 */

require_once("class.WebResponse.php");

define('WEBREQUEST_GET', 0);
define('WEBREQUEST_POST', 1);
define('WEBREQUEST_PUT', 2);
define('WEBREQUEST_DELETE', 3);

class WebRequest {
    protected $content_type = 'text/xml';
    protected $data = null;
    protected $headers = array();
    protected $user_agent = null;

    public function __construct($request_url, $request_method) {
        $this->url = $request_url;
        $this->method = $request_method;
    }

    public function set_data($data) {
        $this->data = $data;
    }

    public function set_auth($user, $pass) {
        $this->user = $user;
        $this->pass = $pass;
    }

    public function add_header($key, $value) {
        // XXX needs encoding?
        $this->headers[] = "{$key}: {$value}";
    }

    public function send() {
        // this is for PUT method
        $tmp_file = null;

        // initialize the curl engine
        $curl = curl_init();
        assert(is_array($this->headers));
        $headers = $this->headers;
        $headers[] = "Content-Type: {$this->content_type}";
    
        if (!isset($this->url) || !is_string($this->url) || empty($this->url)) {
            throw new Exception('URL must be defined.');
        }

        // do not check the name of SSL certificate of the remote server
        curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 0);

        // do not check up the remote server certificate
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);

        // pass in the header elements
        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);

        // set our own User-Agent:
        if (($this->user_agent !== null) && is_string($this->user_agent)) {
            curl_setopt($curl, CURLOPT_USERAGENT, $this->user_agent);
        }

        // pass in the user/pass
        if (($this->user !== null) && ($this->pass !== null)) {
            curl_setopt($curl, CURLOPT_USERPWD, "{$this->user}:{$this->pass}");
        }

        // pass in the url of the target server
        curl_setopt($curl, CURLOPT_URL, $this->url);

        // tell CURL to return the result rather than to load it to the browser
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);

        // pass in the packet to deliver
        switch ($this->method) {
            case WEBREQUEST_PUT:
                $tmp_file = $this->_create_tmp_file($this->data);
                curl_setopt($curl, CURLOPT_PUT, true);
                curl_setopt($curl, CURLOPT_INFILE, $tmp_file);
                curl_setopt($curl, CURLOPT_INFILESIZE, strlen($this->data));
                break;

            case WEBREQUEST_GET:
                break;

            default:
                throw new Exception('Invalid method specified.');
        }
    
        // perform the CURL request and return the result
        $retval = curl_exec($curl);

        // close our temp file, if its been used
        if ($tmp_file !== null) {
            fclose($tmp_file);
        }

        // Check if any error occured
        if(curl_errno($curl)) {
            throw new Exception('Curl error: ' . curl_error($curl));
        } 

        $response = new WebResponse(curl_getinfo($curl), $retval);

        // close the CURL session
        curl_close($curl); 

        return $response;
    }

    protected function _create_tmp_file($data) {
        $tmp_file = tmpfile();

        if ($tmp_file === false) {
            throw new Exception("Unable to create a temporary file.");
        }

        fwrite($tmp_file, $data);
        fseek($tmp_file, 0);
        return $tmp_file;
    }
}
