<?php

/* vim:et:sw=4:ts=4
 *
 * Copyright (c) 2008 LinuxMagic Inc., All Rights Reserved.
 *
 * $Id: basic_stats.php 916 2009-06-04 16:04:44Z shaun $
 *
 * HTML output for stats section including form with select field and inline javascript
 */

/**
 * label is set to constant DS_label . $month_name
 * @var string $name
 */
$name = intl('DS_label') . " " . $month_name;

// if $year is set then label is set to constant DS_label . $year
if (isset($year)) {
    $name .= " " . $year;
}

/**
 * description is set to constant DS_blurb
 * @var string $desc
 */
$desc = intl('DS_blurb');

/**
 * include section header file
 */
include("section.header.php");


// size of each unit
$TBHEIGHT = 150;

/**
 * Finds the greatest value between ham, spam, and exempt.  This is used for rendering the size of the graph
 *
 * @params array $data
 * @return integer $top_value -need to verify integer
 */
function get_top_value($data)
{
    if (!isset($data) || !is_array($data)) {
        return 0;
    }
    $top_value = 0;

    foreach ($data as $d) {
        if ($d['ham'] > $top_value) {
            $top_value = $d['ham'];
        }
        if ($d['spam'] > $top_value) {
            $top_value = $d['spam'];
        }
        if ($d['exempt'] > $top_value) {
            $top_value = $d['exempt'];
        }
    }
    return $top_value;
}

/**
 * Output stats with select field
 *
 * @param array $data list containing data to be output
 * @param int $top_value used to control max value on graph
 * @param int $TBHEIGHT used to conrol size of units
 *
 */
function render_day_stat($data,$top_value,$TBHEIGHT)
{
    if (!isset($data) || !is_array($data)) {
        return;
    }

    $pct_ham = $data['ham'] / $top_value * $TBHEIGHT;
    $pct_spam = $data['spam'] / $top_value * $TBHEIGHT;
    $pct_exempt = $data['exempt'] / $top_value * $TBHEIGHT;

    $pos = 0;

    echo <<<END
<div class="ham" style="height: {$pct_ham}px;left:{$pos}px;">
&nbsp;
</div>
END;
    $pos += 7;
    echo <<<END
<div class="spam" style="height: {$pct_spam}px;left:{$pos}px;">
&nbsp;
</div>
END;
    $pos += 7;
    echo <<<END
<div class="exempt" style="height: {$pct_exempt}px;left:{$pos}px;">
&nbsp;
</div>
END;
}

?>

<script type="text/javascript">

function toggleStat(stat)
{
    var rules = new Array();
    var nsheets = document.styleSheets.length;
    var c = 0;
    for ( c = 0; c < nsheets; c++ ) {
        if (document.styleSheets[c].cssRules) {
            rules = document.styleSheets[c].cssRules;
        } else if (document.styleSheets[c].rules) {
            rules = document.styleSheets[c].rules;
        }
        var nrules = rules.length;
        var d = 0;
        for (d = 0; d < nrules; d++) {
            if (rules[d].selectorText) {
                var rselector = rules[d].selectorText;
                if (rselector.search(stat) == 0) {
                    var curval = rules[d].style.visibility;
                    if (curval == "hidden") {
                        rules[d].style.visibility = "visible";
                    } else {
                        rules[d].style.visibility = "hidden";
                    }
                    d = nrules;
                    c = nsheets;
                }
            }
        }
    }
}

</script>
<form id="month_select" method="post" action="<?php echo $thisPage; ?>">
<select name="active_month" onchange="this.form.submit();">
<option value="1" <?php if ($month == 1) echo "selected" ?>><?php echo intl('DS_jan');?></option>
<option value="2" <?php if ($month == 2) echo "selected" ?>><?php echo intl('DS_feb');?></option>
<option value="3" <?php if ($month == 3) echo "selected" ?>><?php echo intl('DS_mar');?></option>
<option value="4" <?php if ($month == 4) echo "selected" ?>><?php echo intl('DS_apr');?></option>
<option value="5" <?php if ($month == 5) echo "selected" ?>><?php echo intl('DS_may');?></option>
<option value="6" <?php if ($month == 6) echo "selected" ?>><?php echo intl('DS_jun');?></option>
<option value="7" <?php if ($month == 7) echo "selected" ?>><?php echo intl('DS_jul');?></option>
<option value="8" <?php if ($month == 8) echo "selected" ?>><?php echo intl('DS_aug');?></option>
<option value="9" <?php if ($month == 9) echo "selected" ?>><?php echo intl('DS_sep');?></option>
<option value="10" <?php if ($month == 10) echo "selected" ?>><?php echo intl('DS_oct');?></option>
<option value="11" <?php if ($month == 11) echo "selected" ?>><?php echo intl('DS_nov');?></option>
<option value="12" <?php if ($month == 12) echo "selected" ?>><?php echo intl('DS_dec');?></option>
</select>
</form>

<?php

// cycle through stats and output if set
if (isset($stats) && is_array($stats)) {
    $n_days = sizeof($stats);
    $tbwidth = $n_days * 21 + 2;

    $top_value = get_top_value($stats);

    echo "<div id=\"daystats\" style=\"width:{$tbwidth}px;\">";
    $pos = 2;
    for ($c = 1; $c <= $n_days; $c++) {
        echo <<<END
<div id="row_{$c}" class="row" style="left:{$pos}px;">
END;
       // echo "<div class=\"row\" style=\"left:{$pos}px;\">";
        echo "<div class=\"count\">$c</div>";
        render_day_stat($stats[$c],$top_value,$TBHEIGHT-25);

        echo "<div class=\"tooltip\">\n";
        $stats_string = sprintf("<h3>%s %02d</h3><br><span class=\"stat_label\">%s: </span><span class=\"stat_num\">%s</span><br><span class=\"stat_label\">%s: </span><span class=\"stat_num\">%s</span><br><span class=\"stat_label\">%s: </span><span class=\"stat_num\">%s</span><br><span class=\"stat_label\">%s: </span><span class=\"stat_num\">%s</span>"
                               ,$month_name
                               ,$c
                               ,intl('DS_total')
                               ,number_format($stats[$c]['ham'] + $stats[$c]['spam'] + $stats[$c]['exempt'])
                               ,intl('DS_spam')
                               ,number_format($stats[$c]['spam'])
                               ,intl('DS_ham')
                               ,number_format($stats[$c]['ham'])
                               ,intl('DS_exempt')
                               ,number_format($stats[$c]['exempt'])
                               );

        echo $stats_string;
        echo "</div>\n";
        echo "</div>\n";
        $pos += 21;
    }
}
?>

<?php
/**
 * label set to language specific constant DS_exempt
 * @var string $exemptlbl
 */
$exemptlbl = intl('DS_exempt');

/**
 * label set to language specific constant DS_spam
 * @var string $spamlbl
 */
$spamlbl = intl('DS_spam');

/**
 * label set to language specific constant DS_ham
 * @var string $hamlbl
 */
$hamlbl = intl('DS_ham');

/**
 * label set to language specific constant DS_average
 * @var string $avelbl
 */
$avelbl = intl('DS_average');


// output legend if stats are set
if (isset($stats) && is_array($stats)) {

    echo <<<END
</div>
<ul id="daystatslegend">
    <li class="legend-exempt"><span class="block exempt"></span>
        <a onclick="toggleStat('.exempt');">
        {$exemptlbl} 
        </a>
    </li>
    <li class="legend-spam"><span class="block spam"></span>
        <a onclick="toggleStat('.spam');">
        {$spamlbl}
        </a>
    </li>
    <li class="legend-ham"><span class="block ham"></span>
        <a onclick="toggleStat('.ham');">
        {$hamlbl}
        </a>
    </li>
</ul>

<p>{$avelbl}: {$daily_average}</p>
END;
}

/**
 * include section footer file
 */
include("section.footer.php");

?>
